﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Diagnostics;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows.Forms;
using Infragistics.Portable.Components.UI;
using Infragistics.Win;
using Infragistics.Win.DataVisualization;

namespace WDC_ChrossharValues
{
    public partial class Form1 : Form
    {
        ColumnSeries columnSeries;
        CategoryDateTimeXAxis xAxis;
        NumericYAxis yAxis;
      
        private bool hasRepainted = false;

        public Form1()
        {
            InitializeComponent();
        }

        private void Form1_Load(object sender, EventArgs e)
        {
            DataTable categoryTable = CreateCategoryTable();

            xAxis = new CategoryDateTimeXAxis();
            xAxis.DataSource = categoryTable;
            xAxis.DateTimeMemberPath = "Dates";

            yAxis = new NumericYAxis();
            yAxis.MinimumValue = 0;

            columnSeries = new ColumnSeries();
            columnSeries.DataSource = categoryTable;
            columnSeries.XAxis = xAxis;
            columnSeries.YAxis = yAxis;
            columnSeries.ValueMemberPath = "Values";

            ultraDataChart1.Axes.Add(xAxis);
            ultraDataChart1.Axes.Add(yAxis);

            ultraDataChart1.Series.Add(columnSeries);

            ultraDataChart1.CrosshairVisibility = Visibility.Visible;
            columnSeries.TooltipContentUpdating += columnSeries_TooltipContentUpdating;
        }

        System.Windows.Forms.Control columnSeries_TooltipContentUpdating(object sender, ChartTooltipContentEventArgs e)
        {
            var row = e.DataContext.Item as DataRowView;
            if(row != null)
            {

                var date = row.Row.Field<DateTime>("Dates");
                var value = row.Row.Field<int>("Values");

                tooltipLabel.Text = String.Format("Date: {0}\nValue: {1}", date, value);
                
                return tooltipLabel;
            }
            return null;
        }


        private DataTable CreateCategoryTable()
        {
            DataTable dt = new DataTable();
            dt.Columns.Add("Dates", typeof(DateTime));
            dt.Columns.Add("Values", typeof(int));

            dt.Rows.Add(new object[] { DateTime.Today, 200 });
            dt.Rows.Add(new object[] { DateTime.Today.AddDays(1), 280 });
            dt.Rows.Add(new object[] { DateTime.Today.AddDays(2), 160 });
            dt.Rows.Add(new object[] { DateTime.Today.AddDays(3), 120 });
            dt.Rows.Add(new object[] { DateTime.Today.AddDays(4), 221 });
            dt.Rows.Add(new object[] { DateTime.Today.AddDays(5), 144 });
            dt.Rows.Add(new object[] { DateTime.Today.AddDays(6), 198 });
            dt.Rows.Add(new object[] { DateTime.Today.AddDays(7), 220 });
            dt.Rows.Add(new object[] { DateTime.Today.AddDays(8), 245 });
            dt.Rows.Add(new object[] { DateTime.Today.AddDays(9), 208 });
            dt.Rows.Add(new object[] { DateTime.Today.AddDays(10), 180 });
            dt.Rows.Add(new object[] { DateTime.Today.AddDays(11), 202 });

            return dt;
        }



    }


}
